---
name: "✨ Feature request"
about: "Suggest an idea for this project"
title: "✨ Title"
labels: ["feat request"]
assignees: ['']
---

### Is your feature request related to a problem?
A clear and concise description of what the problem is.
If an bug report exists please link it here.

### Describe the behaviour you'd like
A clear and concise description of what you want to happen.

### Describe alternative software applications you've considered using
A clear and concise description of any alternative software applications you've considered.

### Describe workarounds you've implemented while the feature request is being reviewed
If you can, add code snippets of any workaround you've implemented

### Additional context
Add any other context or screenshots about the feature request here.
